#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_GOLD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_GOLD_HPP_INCLUDED

#include <boost/simd/constant/include/constants/gold.hpp>

#endif
